==> jc-1.4.0.tar.gz: java/nio/channels/AlreadyConnectedException.h <==
// public class java.nio.channels.AlreadyConnectedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a699bdbd509fedcd java_nio_channels_AlreadyConnectedException

// header file dependencies
// @dep_header java_lang_IllegalStateException

#include "java/lang/IllegalStateException.h"

#ifndef _JC_java_nio_channels_AlreadyConnectedException_H_
#define _JC_java_nio_channels_AlreadyConnectedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_AlreadyConnectedException$sub_refs	_jc_java_nio_channels_AlreadyConnectedException$sub_refs;
typedef struct _jc_java_nio_channels_AlreadyConnectedException$sub_nonrefs	_jc_java_nio_channels_AlreadyConnectedException$sub_nonrefs;
typedef struct _jc_java_nio_channels_AlreadyConnectedException$refs	_jc_java_nio_channels_AlreadyConnectedException$refs;
typedef struct _jc_java_nio_channels_AlreadyConnectedException$nonrefs	_jc_java_nio_channels_AlreadyConnectedException$nonrefs;
typedef struct _jc_java_nio_channels_AlreadyConnectedException$object	_jc_java_nio_channels_AlreadyConnectedException$object;

typedef const struct _jc_java_nio_channels_AlreadyConnectedException$vmethods	_jc_java_nio_channels_AlreadyConnectedException$vmethods;
typedef const struct _jc_java_nio_channels_AlreadyConnectedException$vtable	_jc_java_nio_channels_AlreadyConnectedException$vtable;
typedef const struct _jc_java_nio_channels_AlreadyConnectedException$vtype	_jc_java_nio_channels_AlreadyConnectedException$vtype;

// Constructors
extern void _jc_java_nio_channels_AlreadyConnectedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_AlreadyConnectedException$object *);

// Virtual methods structure
struct _jc_java_nio_channels_AlreadyConnectedException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_AlreadyConnectedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
	_jc_java_nio_channels_AlreadyConnectedException$vmethods	java_nio_channels_AlreadyConnectedException;
};

// Vtype
struct _jc_java_nio_channels_AlreadyConnectedException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_AlreadyConnectedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_AlreadyConnectedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_AlreadyConnectedException$refs {
    _jc_java_nio_channels_AlreadyConnectedException$sub_refs	java_nio_channels_AlreadyConnectedException;
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_AlreadyConnectedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_AlreadyConnectedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
    _jc_java_nio_channels_AlreadyConnectedException$sub_nonrefs	java_nio_channels_AlreadyConnectedException;
};

// Object instance structure
struct _jc_java_nio_channels_AlreadyConnectedException$object {
	_jc_java_nio_channels_AlreadyConnectedException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_AlreadyConnectedException$vtype	*vtype;
	_jc_java_nio_channels_AlreadyConnectedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_AlreadyConnectedException$vtype _jc_java_nio_channels_AlreadyConnectedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_AlreadyConnectedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_AlreadyConnectedException$class_object;

#endif	/* _JC_java_nio_channels_AlreadyConnectedException_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/AlreadyConnectedException.h <==
// public class java.nio.channels.AlreadyConnectedException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class b7e704701c278e65 java_lang_IllegalStateException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class a699bdbd509fedcd java_nio_channels_AlreadyConnectedException

// header file dependencies
// @dep_header java_lang_IllegalStateException

#include "java/lang/IllegalStateException.h"

#ifndef _JC_java_nio_channels_AlreadyConnectedException_H_
#define _JC_java_nio_channels_AlreadyConnectedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_AlreadyConnectedException$sub_refs	_jc_java_nio_channels_AlreadyConnectedException$sub_refs;
typedef struct _jc_java_nio_channels_AlreadyConnectedException$sub_nonrefs	_jc_java_nio_channels_AlreadyConnectedException$sub_nonrefs;
typedef struct _jc_java_nio_channels_AlreadyConnectedException$refs	_jc_java_nio_channels_AlreadyConnectedException$refs;
typedef struct _jc_java_nio_channels_AlreadyConnectedException$nonrefs	_jc_java_nio_channels_AlreadyConnectedException$nonrefs;
typedef struct _jc_java_nio_channels_AlreadyConnectedException$object	_jc_java_nio_channels_AlreadyConnectedException$object;

typedef const struct _jc_java_nio_channels_AlreadyConnectedException$vmethods	_jc_java_nio_channels_AlreadyConnectedException$vmethods;
typedef const struct _jc_java_nio_channels_AlreadyConnectedException$vtable	_jc_java_nio_channels_AlreadyConnectedException$vtable;
typedef const struct _jc_java_nio_channels_AlreadyConnectedException$vtype	_jc_java_nio_channels_AlreadyConnectedException$vtype;

// Constructors
extern void _jc_java_nio_channels_AlreadyConnectedException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_AlreadyConnectedException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_AlreadyConnectedException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_AlreadyConnectedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalStateException$vmethods	java_lang_IllegalStateException;
	_jc_java_nio_channels_AlreadyConnectedException$vmethods	java_nio_channels_AlreadyConnectedException;
};

// Vtype
struct _jc_java_nio_channels_AlreadyConnectedException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_AlreadyConnectedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_AlreadyConnectedException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_AlreadyConnectedException$refs {
    _jc_java_nio_channels_AlreadyConnectedException$sub_refs	java_nio_channels_AlreadyConnectedException;
    _jc_java_lang_IllegalStateException$sub_refs	java_lang_IllegalStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_AlreadyConnectedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_AlreadyConnectedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalStateException$sub_nonrefs	java_lang_IllegalStateException;
    _jc_java_nio_channels_AlreadyConnectedException$sub_nonrefs	java_nio_channels_AlreadyConnectedException;
};

// Object instance structure
struct _jc_java_nio_channels_AlreadyConnectedException$object {
	_jc_java_nio_channels_AlreadyConnectedException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_AlreadyConnectedException$vtype	*vtype;
	_jc_java_nio_channels_AlreadyConnectedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_AlreadyConnectedException$vtype _jc_java_nio_channels_AlreadyConnectedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_AlreadyConnectedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_AlreadyConnectedException$class_object;

#endif	/* _JC_java_nio_channels_AlreadyConnectedException_H_ */
